@@ -31,10 +31,10 @@ class Python3Backend : public PythonBackend
     Cantor::Session* createSession();
 
     QString id() const;
-    KUrl helpUrl() const;
+    QUrl helpUrl() const;
     QString description() const;
    
     KConfigSkeleton* config() const;
 };
 
-#endif
\ No newline at end of file
+#endif
