@@ -21,6 +21,7 @@
 #ifndef CANTOR_H
 #define CANTOR_H
 
+#include <QObject>
 #include <KParts/MainWindow>
 
 #include <QList>
@@ -30,6 +31,10 @@
 class QTabWidget;
 class KTextEdit;
 
+namespace Cantor{
+class WorksheetAccessInterface;
+};
+
 /**
  * This is the application "Shell".  It has a menubar, toolbar, and
  * statusbar but relies on the "Part" to do all the real work.
@@ -58,6 +63,7 @@ public:
      */
     bool hasAvailableBackend();
 
+    Cantor::WorksheetAccessInterface* currentWorksheetAccessInterface();
 protected:
     /**
      * This method is called when it is time for the app to save its
