@@ -23,7 +23,7 @@
 
 #include <KXMLGUIClient>
 #include <QObject>
-#include <KPluginInfo>
+#include <KPluginMetaData>
 
 #include "backend.h"
 
@@ -53,10 +53,10 @@ class CANTOR_EXPORT PanelPlugin : public QObject /*, public KXMLGUIClient*/
 
     /**
      * Sets the properties of this PanelPlugin
-     * accodring to KPluginInfo
-     * @param info KPluginInfo
+     * accodring to KPluginMetaData
+     * @param info KPluginMetaData
      */
-    void setPluginInfo(KPluginInfo info);
+    void setPluginInfo(KPluginMetaData info);
 
     /**
      * Returns a list of all extensions, the current backend
