@@ -21,8 +21,9 @@
 #include "cantor.h"
 #include <QApplication>
 #include <KAboutData>
+#include <KCrash>
 #include <Kdelibs4ConfigMigrator>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KConfigGroup>
 #include <QCommandLineParser>
 
@@ -36,6 +37,9 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
 
+    // TODO: for >=KF5.15 use KCrash::initialize();
+    KCrash::setCrashHandler(KCrash::defaultCrashHandler);
+
     // Migrating configuration from 4.x applications to KF5-based applications
     QStringList configFiles;
     QStringList rcFiles;
