@@ -50,10 +50,10 @@ class PageBreakEntry : public WorksheetEntry
     //void paint(QPainter* painter, const QStyleOptionGraphicsItem * option,
     //         QWidget * widget = 0);
 
-  public slots:
+  public Q_SLOTS:
     bool evaluate(EvaluationOption evalOp = FocusNext);
     void updateEntry();
-    void populateMenu(KMenu *menu, const QPointF& pos);
+    void populateMenu(QMenu *menu, const QPointF& pos);
 
   protected:
     bool wantToEvaluate();
