@@ -29,18 +29,16 @@
 #include <QtXmlPatterns/QXmlQuery>
 #include <QtXmlPatterns/QXmlNamePool>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <QIcon>
 
 #include <KMessageBox>
 #include <KActionCollection>
-#include <KShortcut>
 #include <QAction>
 #include <KFontAction>
 #include <KFontSizeAction>
 #include <KSelectAction>
 #include <KToggleAction>
-#include <KColorDialog>
 #include <KColorScheme>
 
 #include "config-cantor.h"
@@ -382,7 +380,7 @@ void Worksheet::invalidateLastEntry()
 
 WorksheetEntry* Worksheet::entryAt(qreal x, qreal y)
 {
-    QGraphicsItem* item = itemAt(x, y);
+    QGraphicsItem* item = itemAt(x, y, QTransform());
     while (item && (item->type() <= QGraphicsItem::UserType ||
                     item->type() >= QGraphicsItem::UserType + 100))
         item = item->parentItem();
@@ -829,15 +827,37 @@ QDomDocument Worksheet::toXML(KZip* archive)
 }
 
 void Worksheet::save( const QString& filename )
+{
+    QFile file(filename);
+    if ( !file.open(QIODevice::WriteOnly) )
+    {
+        KMessageBox::error( worksheetView(),
+                            i18n( "Cannot write file %1." , filename ),
+                            i18n( "Error - Cantor" ));
+        return;
+    }
+
+    save(&file);
+}
+
+QByteArray Worksheet::saveToByteArray()
+{
+    QBuffer buffer;
+    save(&buffer);
+
+    return buffer.buffer();
+}
+
+void Worksheet::save( QIODevice* device)
 {
     qDebug()<<"saving to filename";
-    KZip zipFile( filename );
+    KZip zipFile( device );
 
 
     if ( !zipFile.open(QIODevice::WriteOnly) )
     {
         KMessageBox::error( worksheetView(),
-                            i18n( "Cannot write file %1." , filename ),
+                            i18n( "Cannot write file." ),
                             i18n( "Error - Cantor" ));
         return;
     }
@@ -915,9 +935,24 @@ void Worksheet::saveLatex(const QString& filename)
 }
 
 void Worksheet::load(const QString& filename )
+{
+    QFile file(filename);
+    if (!file.open(QIODevice::ReadOnly))
+        return ;
+    load(&file);
+
+}
+
+void Worksheet::load(QByteArray* data)
+{
+    QBuffer buf(data);
+    load(&buf);
+}
+
+void Worksheet::load(QIODevice* device)
 {
     // m_file is always local so we can use QFile on it
-    KZip file(filename);
+    KZip file(device);
     if (!file.open(QIODevice::ReadOnly))
         return ;
 
@@ -1059,7 +1094,7 @@ void Worksheet::populateMenu(QMenu *menu, const QPointF& pos)
     WorksheetEntry* entry = entryAt(pos);
     if (entry && !entry->isAncestorOf(m_lastFocusedTextItem)) {
         WorksheetTextItem* item =
-            qgraphicsitem_cast<WorksheetTextItem*>(itemAt(pos));
+            qgraphicsitem_cast<WorksheetTextItem*>(itemAt(pos, QTransform()));
         if (item && item->isEditable())
             m_lastFocusedTextItem = item;
     }
